#
# spec file for package libgovirt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgovirt
Version:        0.3.9
Release:        2.5
Summary:        GObject based oVirt bindings
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://gitlab.gnome.org/GNOME/libgovirt
Source0:        https://download.gnome.org/sources/libgovirt/0.3/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM bae26c0033d649722b5a3fc48df3adf2172490f1.patch -- Suppress error 'cast increases required alignment of target type'
Patch0:         https://gitlab.gnome.org/GNOME/libgovirt/-/commit/bae26c0033d649722b5a3fc48df3adf2172490f1.patch

BuildRequires:  gobject-introspection-devel >= 1.30.0
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.66.0
BuildRequires:  pkgconfig(rest-1.0) >= 0.9

%description
GoVirt is a GObject wrapper for the oVirt REST API [1]. It will
only provide very basic functionality as the goal is to
autogenerate a full wrapper as it is already done for the python
bindings.

%package -n libgovirt2
Summary:        GObject based oVirt bindings
# To make the lang package installable
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n libgovirt2
GoVirt is a GObject wrapper for the oVirt REST API [1]. It will
only provide very basic functionality as the goal is to
autogenerate a full wrapper as it is already done for the python
bindings.

%package -n typelib-1_0-GoVirt-1_0
Summary:        Introspection bindings for the GObject-based oVirt bindings
Group:          System/Libraries

%description -n typelib-1_0-GoVirt-1_0
GoVirt is a GObject wrapper for the oVirt REST API [1]. It will
only provide very basic functionality as the goal is to
autogenerate a full wrapper as it is already done for the python
bindings.

%package devel
Summary:        Development files for the GObject-based oVirt bindings
Group:          Development/Languages/C and C++
Requires:       libgovirt2 = %{version}
Requires:       typelib-1_0-GoVirt-1_0 = %{version}

%description devel
GoVirt is a GObject wrapper for the oVirt REST API [1]. It will
only provide very basic functionality as the goal is to
autogenerate a full wrapper as it is already done for the python
bindings.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang govirt-1.0 %{?no_lang_C}

%ldconfig_scriptlets -n libgovirt2

%files -n libgovirt2
%license COPYING
%doc README
%{_libdir}/libgovirt.so.*

%files -n typelib-1_0-GoVirt-1_0
%{_libdir}/girepository-1.0/GoVirt-1.0.typelib

%files devel
%{_datadir}/gir-1.0/GoVirt-1.0.gir
%{_includedir}/govirt-1.0/
%{_libdir}/libgovirt.so
%{_libdir}/pkgconfig/govirt-1.0.pc

%files lang -f govirt-1.0.lang

%changelog
* Fri Oct  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add bae26c0033d649722b5a3fc48df3adf2172490f1.patch: Suppress
  error 'cast increases required alignment of target type'.
* Sat Aug 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.9:
  + Update librest dependency to 0.9.
  + Update to libsoup3.
  + Remove autotools in favor of meson.
  + Updated translations.
- Replace pkgconfig(rest-0.7) with pkgconfig(rest-1.0)
  BuildRequires following upstream changes.
- Add meson BuildRequires and macros.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Feb 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.3.8:
  + Various API additions.
  + Initial support for Disks.
  + Properly handle StorageDomains of DATA type.
  + Fixed crash with error handling of GTask API.
  + Updated translations.
* Fri Jan 31 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.7:
  + Use GTask API instead of deprecated GSimpleAsyncResult.
  + Fixed issue preventing adding parameters to action.
  + Prefer certificate from XML data instead of the command line.
  + Added support for oVirt API v4.
  + Initial support for building with meson, should be replacing
    autotools in future release.
  + Updated translations.
- Update URL and modernize spec.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon May 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.6:
  + Fixed distcheck build by renewing tests certificates which had
    been expired.
  + Updated translations.
- Changes from version 0.3.5:
  + API additions.
  + Force use of v3 REST API.
  + Fix crash on 404.
  + Fix persistent session with oVirt 3.6.
  + Support for new storage format added in oVirt 4.1.
  + New unified mode for parsing nodes using a single struct.
  + Initial support for hosts/clusters/datacenters.
  + Support for searching queries of collections.
  + New nodes can be created with name/uuid only, but require
    explicit refresh() call to retrieve attributes/subnodes.
  + Improved error messages in case of error in async call.
  + Updated translations.
* Mon Mar  5 2018 jengelh@inai.de
- Fix SRPM group. Update summaries. Fix faulty disable-static
  switch.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Apr 13 2016 zaitor@opensuse.org
- Update to version 0.3.4:
  + API additions:
  - ovirt_proxy_get_api().
  - OvirtVmDisplay::ca-cert.
  - OvirtCollection::resources.
  - OvirtProxy::sso-token.
  + Fixes to CA certificate handling.
  + Fix crash when a REST API call returned multiple elements with
    the same 'name' attribute.
  + Various leak fixes.
  + Improved API documentation.
  + Fix GCancellable disconnection after async calls.
  + Updated translations.
- Add pkgconfig(gthread-2.0) BuildRequires and version it:
  Configure checks for it.
* Wed Apr  8 2015 dimstar@opensuse.org
- Update to version 0.3.3:
  + Add support for SPICE proxy.
  + Don't report REST call cancellations as an unexpected error.
  + Access REST API through /ovirt-engine/api rather than /api as
    the latter is deprecated.
  + Parse status of storage domains.
  + Add support for GOVIRT_DISABLE_HTTPS and GOVIRT_NO_SSL_STRICT
    environment variable in order to make it easier to lower
    security during development/testing.
  + Fix compilation with older glibs.
  + Fix mingw build.
  + Updated translations.
* Thu Oct  9 2014 zaitor@opensuse.org
- Update to version 0.3.2:
  + Allow empty filenames in OvirtCdrom, this allows to remove the
    current CD image from a VM.
  + Parse leading '~' when handling commandline filenames.
  + Implemented ovirt_resource_delete() and its async variant.
  + Add translation support.
  + Bug fixes.
  + Updated translations.
- Add intltool BuildRequires: New dependency.
- Add lang macros, and package the new translations. Add Recommends
  for the new lang package (and make libgovirt2 provide libgovirt,
  so that the lang package is installable).
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 0.3.1:
  + Handle cookies set by the oVirt instance in order to have some
    'persistant' authentication through the JSESSIONID cookie.
  + Add support for VM pools.
  + Added ovirt_resource_refresh{_async} in order to refetch a
    resource content remotely.
  + Various leak/memory-handling related bug fixes.
  + ovirt_proxy_new now expects a hostname without the https:// and
    the /api part hostnames with http/https/api will still work
    fine but will cause runtime warnings.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 0.3.0:
  + Add support for listing storage domains and the files they
    contain.
  + Add support for changing the CDRom available in a VM.
  + Introduced an OvirtApi class which represents the toplevel
    oVirt collection from which one can access VMs, storage
    domains, ...
  + Rework certificate handling, OvirtProxy now has a 'ssl-ca-file'
    property that can be used to specify which CA certificate
    should be used to validate remote certificates.
  + Certificate checking is now enforced by default unless
    OvirtProxy::ssl-strict is set to FALSE.
  + ABI/API hasn't been broken, even though some functions were
    deprecated.
* Tue Jul  9 2013 dimstar@opensuse.org
- Update to version 0.2.0:
  + Break ABI :(.
  + Switch back to using GSimpleAsyncResult (from GTask) to gain
    compatibility with older glib versions.
  + Refactor internals to make it much easier to add support for
    more REST collections.
  + Parse more VM states from the OvirtVm resource.
- Rename libgovirt1 subpackage to libgovirt2, following upstreams
  soname change.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 0.1.0:
  + Add OvirtVmDisplay::host_subject property, this is required in
    some cases to connect to a VM which is using SPICE.
  + Add OvirtVmDisplay::smartcard and OvirtVmDisplay::allow-override
    properties.
  + Implement ovirt_vm_refresh_async().
* Sat Mar  9 2013 dimstar@opensuse.org
- Initial package, version 0.0.3.
